YPayAndroidPlatform class

An YPayPlatform that wraps YPay Android SDK.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init({required Configuration configuration}) Future<void>
Initializes the SDK for further work.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paymentResultStream() Stream<String>
Returns a Stream of payment results.
startPayment({required String url}) Future<void>
Starts payment process.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerPlatform() → void
Registers this class as the default instance of YPayPlatform.