registerPlatform static method

void registerPlatform()

Registers this class as the default instance of YPayPlatform.

Implementation

static void registerPlatform() {
  /// Register the platform instance with the plugin platform interface.
  YPayPlatform.instance = YPayAndroidPlatform._();
}